@@ -1,4 +1,4 @@
-from rate_limit.decorators import rate_limit
+from django_rate_limit_redis.decorators import rate_limit
 from rest_framework.routers import DefaultRouter
 
 from django.urls import include
