@@ -2,7 +2,7 @@ import abc
 import json
 from typing import Dict
 
-from rate_limit.decorators import rate_limit
+from django_rate_limit_redis.decorators import rate_limit
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
